# Mamba

Mamba is a framework to write, compile, and deploy smart contracts
written in Vyper language. On top of that, it has supports for writing
and testing decentralized applications using Web3.py and Pytest.

## Dependencies

* [Ganache](https://www.trufflesuite.com/ganache)
* [Pip](https://pypi.org/project/pip/)
* [Python3](https://www.python.org/downloads/) version 3.6 or greater
* [Go Ethereum](https://geth.ethereum.org/downloads/)
* [Vyper](https://github.com/ethereum/vyper)

## Installation

You can install the latest release via ``pip``:

```bash
$ pip install black-mamba
```

## Quick Usage

To set up the the structure of Mamba project directory:

```bash
$ mamba init
$ edit contracts/HelloWorld.vy
$ mamba compile
```

## Documentation

Mamba documentation can be found at [Mamba website](https://mamba.black/documentation).


## Contributing

I invite you to join Mamba squad! You can contribute to Mamba by
writing documentation, finding bugs, and creating pull requests.
